==> haskell-hpack-0.28.2-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.28.2
id: hpack-0.28.2-7EombhWqsc8Hvjcgk5wVYu
key: hpack-0.28.2-7EombhWqsc8Hvjcgk5wVYu
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: afa386f17490f1a3cf4ea4a1a94a4202
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.Defaults Hpack.Syntax.Dependency Hpack.Syntax.Git
                Hpack.Utf8 Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.28.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.28.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hpack-0.28.2
hs-libraries: HShpack-0.28.2-7EombhWqsc8Hvjcgk5wVYu
depends:
    Cabal-2.2.0.1 Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU
    aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi base-4.11.1.0
    bifunctors-5.5.2-GKpLQeXJfoy1hBTQomaJNY bytestring-0.10.8.2
    containers-0.5.11.0 cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    http-client-0.5.13-oP0CuDy48eCryfgf9zAeZ
    http-client-tls-0.3.5.3-87ITordiFeaJxpRGoXUThe
    http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX pretty-1.1.3.6
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    yaml-0.8.30-97tSYKLiZfhArbvodlPug6
abi-depends: Cabal-2.2.0.1=cb731d19f27640e4ae6e4fb9c679c02f
             Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU=fe90daae121092f087f19649a03fe024
             aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi=4bd33a472ed49d1f25a046c18b4acb2d
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bifunctors-5.5.2-GKpLQeXJfoy1hBTQomaJNY=693803e0017373d29c3a9b4a2fb6f37d
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             http-client-0.5.13-oP0CuDy48eCryfgf9zAeZ=dd5944a929261e121fef45baf41c85c5
             http-client-tls-0.3.5.3-87ITordiFeaJxpRGoXUThe=9d0acec7e2888a2f6d8681c2ef67bb98
             http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX=c36ea90c1caed733a7293143960ab603
             pretty-1.1.3.6=242598bba36778e604a1e89d5c7ce1a8
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             yaml-0.8.30-97tSYKLiZfhArbvodlPug6=04274a83990c83497d1b8bd9d4952c5d
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.28.2-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.28.2
id: hpack-0.28.2-5zlHMjGDTU844350urlNTB
key: hpack-0.28.2-5zlHMjGDTU844350urlNTB
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: a524e73cfea592dd9ffdf47b895e8038
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.Defaults Hpack.Syntax.Dependency Hpack.Syntax.Git
                Hpack.Utf8 Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.28.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.28.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hpack-0.28.2
hs-libraries: HShpack-0.28.2-5zlHMjGDTU844350urlNTB
depends:
    Cabal-2.2.0.1 Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU
    aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf base-4.11.1.0
    bifunctors-5.5.2-LCjtSmn3TgtFgxcmd4zGDx bytestring-0.10.8.2
    containers-0.5.11.0 cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    http-client-0.5.13-BDPgLPnNEzzAG7Py70CdWs
    http-client-tls-0.3.5.3-4gGcoaLAGPL3I1eY2hx2qR
    http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq pretty-1.1.3.6
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    yaml-0.8.31-LFFGwjInZqL1Ts7PMt1MmB
abi-depends: Cabal-2.2.0.1=cb731d19f27640e4ae6e4fb9c679c02f
             Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU=fe90daae121092f087f19649a03fe024
             aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf=099629a1e097a2a1a4c1ce1f1c4a7711
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bifunctors-5.5.2-LCjtSmn3TgtFgxcmd4zGDx=fc8750c41d8bee18e82b824d959e12f6
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             http-client-0.5.13-BDPgLPnNEzzAG7Py70CdWs=fa6eec72c73742ffff505285f6de59d8
             http-client-tls-0.3.5.3-4gGcoaLAGPL3I1eY2hx2qR=85b26cc28437727851175622157afe50
             http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq=681a4d4f5ae8e517c4372dabe00b35c0
             pretty-1.1.3.6=242598bba36778e604a1e89d5c7ce1a8
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             yaml-0.8.31-LFFGwjInZqL1Ts7PMt1MmB=2cf90ec3bdb9344cbab8d8c92cc22947
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
